@@ -19,9 +19,9 @@
  ***************************************************************************/
 
 #include "beaglesearch.h"
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqapplication.h>
 #include <kurl.h>
 
