@@ -68,7 +68,7 @@ void KCMBeagleBackends::load( bool useDefaults )
     connect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), TQT_SLOT(gotAvailableBackends(TDEProcess *, char *, int)));
     *proc << "beagled" << "--list-backends";
     if (!proc->start(TDEProcess::Block,TDEProcess::Stdout))
-        kdError("Could not ask Beagle daemon for available backends.");
+        kdError("Could not ask Beagle daemon for available backends.\n");
 
     if (!useDefaults) {
         TQStringList disabledBackends = readDisabledBackends();
