@@ -83,7 +83,7 @@ void KCMBeagle::save()
   *proc << "beagle-config";
   *proc << "--beagled-reload-config";
   if (!proc->start())
-    kdError("Could not make Beagle reload its config.");
+    kdError("Could not make Beagle reload its config.\n");
 }
 
 TQString KCMBeagle::quickHelp() const
