@@ -96,7 +96,7 @@ void KCMKerry::save()
   *proc << "beagle-config";
   *proc << "--beagled-reload-config";
   if (!proc->start())
-    kdError("Could not make Beagle reload its config.");
+    kdError("Could not make Beagle reload its config.\n");
 }
 
 TQString KCMKerry::quickHelp() const
