@@ -22,15 +22,15 @@
 #ifndef __KCMKERRY_H__
 #define __KCMKERRY_H__
 
-#include <kcmodule.h>
+#include <tdecmodule.h>
 
-class KConfig;
+class TDEConfig;
 class TQTabWidget;
 
-class KCMKerry : public KCModule
+class KCMKerry : public TDECModule
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
   KCMKerry(TQWidget *parent=0, const char *name=0);
@@ -41,10 +41,10 @@ public:
   virtual TQString quickHelp() const;
 
 private:
-  KCModule *m_search;
-  KCModule *m_indexing;
-  KCModule *m_backends;
-  KCModule *m_status;
+  TDECModule *m_search;
+  TDECModule *m_indexing;
+  TDECModule *m_backends;
+  TDECModule *m_status;
   TQTabWidget *m_tab;
 };
 
