@@ -22,20 +22,20 @@
 #include "beagle.h"
 #include "kerry.h"
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 
 extern "C"
 {
-  KDE_EXPORT KCModule *create_beagle(TQWidget *parent, const char *name)
+  KDE_EXPORT TDECModule *create_beagle(TQWidget *parent, const char *name)
   {
-    KGlobal::locale()->insertCatalogue("kcmbeagle");
+    TDEGlobal::locale()->insertCatalogue("kcmbeagle");
     return new KCMBeagle(parent, name);
   }
 
-  KDE_EXPORT KCModule *create_kerry(TQWidget *parent, const char *name)
+  KDE_EXPORT TDECModule *create_kerry(TQWidget *parent, const char *name)
   {
-    KGlobal::locale()->insertCatalogue("kcmbeagle");
+    TDEGlobal::locale()->insertCatalogue("kcmbeagle");
     return new KCMKerry(parent, name);
   }
 }
