@@ -73,7 +73,9 @@ KCMBeagleStatus::KCMBeagleStatus(TQWidget *parent, const char * )
     pb_refresh = new KPushButton (i18n("Refresh Status"), footer_box);
     connect (pb_refresh, TQT_SIGNAL (clicked()), this, TQT_SLOT (refreshStatus ()) );
 
+#if !GLIB_CHECK_VERSION( 2,36,0 )
     g_type_init ();
+#endif
     refreshStatus ();
 
     load();
