@@ -224,7 +224,7 @@ void KerryApplication::configure()
 {
     TDEProcess proc;
     proc << "tdecmshell";
-    proc << "kde-kcmkerry.desktop";
+    proc << "kcmkerry.desktop";
     proc.start(TDEProcess::DontCare);
 }
 
